# vim: syntax=gnuplot
# gnuplot

set terminal postscript portrait enhanced mono lw 1 "Helvetica"
set encoding iso_8859_1  # UTF-8 is not working 'R [Å]' so use iso_8859_1 and 'R [{\305}]' for Angstrom
SCALE=2.0
HEIGHT=0.40
set size SCALE*1.0,SCALE*HEIGHT
set origin 0,0

set key top Left  right

set style line 1  lt 1  lc rgb "#ac2217" lw 2
set style line 2  lt 1  lc rgb "#006221" lw 2
set style line 3  lt 1  lc rgb "#033e8e" lw 2
set style line 4  lt 1  lc rgb "#0ba9d8" lw 2
set style line 5  lt 1  lc rgb "#bb4174" lw 2
set style line 6  lt 1  lc rgb "#ddda53" lw 2
set style line 7  lt 1  lc rgb "#343b11" lw 2
set style line 8  lt 1  lc rgb "#2464a1" lw 2
set style line 9  lt 1  lc rgb "#7b0815" lw 2
set style line 10 lt 2  lc rgb "#000000" lw 2

########################################################################
## Constants

_1_Bohr_in_Angstrom = 0.529177210903   # https://physics.nist.gov/cgi-bin/cuu/Value?bohrrada0  0.529177249 or 0.529177210903 or 0.52917721067 grep -E "0\.5291772" --color . -r --include='*py'
_1_Hartree_in_cmInv = 219474.63136320  # https://physics.nist.gov/cgi-bin/cuu/Convert?exp=0&num=1&From=hr&To=minv&Action=Only+show+factor   219474.63136320
_1_Hartree_in_eV    = 27.211386245988  # https://physics.nist.gov/cgi-bin/cuu/Value?hrev   27.211386245988
_1_cmInv_in_eV      = _1_Hartree_in_eV / _1_Hartree_in_cmInv
_1_cmInv_in_meV     = _1_cmInv_in_eV * 1000.0


atomic_time_to_seconds  = 2.418884326509e-17  # http://physics.nist.gov/cuu/Constants/Table/allascii.txt
femto                   = 1.0e-15
DT                      = 0.35*femto

print "DT=".sprintf("%.3f",DT/femto)."fs"

speed_of_light_m_per_s  = 299792458
speed_of_light_cm_per_s = speed_of_light_m_per_s*100

cut_start_lines = 0

Ag2_minus_Autocorrelation  ="Figure_4_Autocorrelation.dat"
LINES_01 = 2508800*1.0
MAX_01   = 83.08050157606864*1.0

set out 'Figure_4.eps'
set grid
set multiplot layout 1,2
SplitX=0.35
set size   ((SCALE*1.0)*(1.0-SplitX)),((SCALE*HEIGHT)*1.0)
set origin ((SCALE*1.0)*(    SplitX)),((SCALE*HEIGHT)*0.0)
set lmargin 0
set rmargin 4.9
set tmargin 2.7
set bmargin 2.8
set format y ''
Ag2_minus_POT_cut_J250_255  = "Figure_4_Ag2_minus_POT_cut_J250_255.dat"
Ag2_minus_wavefunctions     = "Figure_4_Ag2_minus_wavefunctions.dat"
Gaussian_packet             = "Figure_4_Gaussian_packet.dat"
set y2label  'E [meV]' offset -3.0
set y2tics 0.5
set y2tics format '%.1f' offset -0.6
set x2tics 2 offset 0,-0.3
set xlabel 'R [{\305}_{}]' offset 0,0.2
set link x2 via (x / _1_Bohr_in_Angstrom ) inverse (x * _1_Bohr_in_Angstrom)
set x2label  'R [a_0]' offset 0,-0.5
set link y2 via (_1_cmInv_in_meV * y) inverse (y/_1_cmInv_in_meV)
set clip two
set yr[36:68]
set ytics 2 nomirror
set xtics nomirror
set mxtics 4
#set mx2tics 4
set my2tics 5
set mytics 4
set xr[1.5:20]
WF_SCALE=120000.0
EN_155=0.00029053209535280673
EN_154=0.0002814654586928108
EN_153=0.00026912562366111813
EN_152=0.0002542577633845031
EN_151=0.00023712742539489082
EN_150=0.00021785845110997124
EN_149=0.0001965159737097132
EN_148=0.00017313390829653153

shift_y  = 0.75
shift_x1 = 16.1
#arrow_y  = shift_x1+0.002
#arrow_top=         -0.002
v29 = EN_155*_1_Hartree_in_cmInv;  vvv=v29; set label 155 "E_{155}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.300 ) rotate by 0 font "Arial,11" front;
v28 = EN_154*_1_Hartree_in_cmInv;  vvv=v28; set label 154 "E_{154}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.200 ) rotate by 0 font "Arial,11" front;
v27 = EN_153*_1_Hartree_in_cmInv;  vvv=v27; set label 153 "E_{153}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.000 ) rotate by 0 font "Arial,11" front;
v26 = EN_152*_1_Hartree_in_cmInv;  vvv=v26; set label 152 "E_{152}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.000 ) rotate by 0 font "Arial,11" front;
v25 = EN_151*_1_Hartree_in_cmInv;  vvv=v25; set label 151 "E_{151}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.000 ) rotate by 0 font "Arial,11" front;
v24 = EN_150*_1_Hartree_in_cmInv;  vvv=v24; set label 150 "E_{150}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.000 ) rotate by 0 font "Arial,11" front;
v23 = EN_149*_1_Hartree_in_cmInv;  vvv=v23; set label 149 "E_{149}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.000 ) rotate by 0 font "Arial,11" front;
v22 = EN_148*_1_Hartree_in_cmInv;  vvv=v22; set label 148 "E_{148}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1 + 0.000 ),(vvv + shift_y + 0.000 ) rotate by 0 font "Arial,11" front;
set label 1 "{/Symbol F}(R)" at 9.05,66.5 font "Arial,11" front;
plot \
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($2)-EN_155)/( 1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_155*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($3)-EN_154)/(-1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_154*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($4)-EN_153)/(-1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_153*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($5)-EN_152)/( 1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_152*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($6)-EN_151)/(-1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_151*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($7)-EN_150)/( 1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_150*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($8)-EN_149)/(-1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_149*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Ag2_minus_wavefunctions    u (($1) * _1_Bohr_in_Angstrom ):(((($9)-EN_148)/( 1.0*WF_SCALE)) * _1_Hartree_in_cmInv + EN_148*_1_Hartree_in_cmInv) w l lt 1 lw 0.2 notitle,\
    Gaussian_packet            u 1:2 w l lt 1 lw 0.8 notitle,\
    Ag2_minus_POT_cut_J250_255 u (($1) * _1_Bohr_in_Angstrom ):(($8) * _1_Hartree_in_cmInv ) w l lt 2 lw 1.5  notitle "J=254"

set size   ((SCALE*1.0)*(SplitX)),((SCALE*HEIGHT)*1.0)
set origin ((SCALE*1.0)* 0.0    ),((SCALE*HEIGHT)*0.0)

frequency_resolution_01 = 1.0/( DT * LINES_01 )
print "frequency_resolution = ".sprintf("%.6f",frequency_resolution_01)
set mxtics 2
set xlabel 'Intensity' offset 0,0.2
set xlabel 'Intensity{}_{}' offset 0,0.2
set y2label ''
set ylabel 'E [cm^{-1}]' offset 1.3,0
set rmargin 0
set lmargin 5.5
set format y
unset y2tics
set xr[0.95:-0.03]
set link x2 via x inverse x
set x2tics 0.2
unset x2tics
set x2label  'Intensity {}_{}' offset 0,-0.5
unset x2label
shift_y  = 0.77
shift_x1 = 0.39
set xtics 0.2
v29 = 63.7436852841;  vvv=v29; set label 155 "E_{155}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
v28 = 61.7683148224;  vvv=v28; set label 154 "E_{154}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
v27 = 59.0711743842;  vvv=v27; set label 153 "E_{153}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
v26 = 55.8042155437;  vvv=v26; set label 152 "E_{152}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
v25 = 52.0434140877;  vvv=v25; set label 151 "E_{151}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
v24 = 47.8267579098;  vvv=v24; set label 150 "E_{150}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
v23 = 43.1162591165;  vvv=v23; set label 149 "E_{149}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
v22 = 37.9878934947;  vvv=v22; set label 148 "E_{148}=".sprintf("%.2f",vvv)." cm^{-1}" at (shift_x1),(vvv + shift_y) rotate by 0 font "Arial,11" front;
unset label 1

MAX_LINES=0
set clip one
plot Ag2_minus_Autocorrelation u 2:1 w l ls  1 title ''

unset multiplot

